@@ -4,5 +4,5 @@
 
 # Copyright 2022 Oxide Computer Company
 
-from duro_rest.error import AuthenticationError, ForbiddenError, NotFoundError
+from duro_rest.error import AuthenticationError, BadRequestError, ForbiddenError, NotFoundError
 from duro_rest.duro_client import Client
\ No newline at end of file
