@@ -8,6 +8,10 @@ class AuthenticationError(Exception):
   def __init__(self, message):
     super().__init__(message)
 
+class BadRequestError(Exception):
+  def __init__(self, message, errors):
+    super().__init__(message, errors)
+
 class ForbiddenError(Exception):
   def __init__(self, message):
     super().__init__(message)
